#!/usr/bin/env python

# run script for the nifi service.

from __future__ import print_function

import os
import sys
import logging
import jinja2
from maestro.guestutils import *
from distutils.dir_util import copy_tree

# setup logging
logger = logging.getLogger('com.cenx.deployer.nifi')
logger.setLevel(logging.INFO)
ch = logging.StreamHandler()
ch.setLevel(logging.INFO)
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
ch.setFormatter(formatter)
logger.addHandler(ch)

NIFI_HOME = os.environ.get('NIFI_HOME')

def render(name, conf):
  """ Render configuration file from template.
  """
  template_file = '/opt/nifi_CENX/{}'.format(name)
  output_file = '{}/conf/{}'.format(NIFI_HOME, name)

  env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(os.path.dirname(template_file)),
    extensions=['jinja2.ext.with_'], trim_blocks=True)
  try:
    template = env.get_template(os.path.basename(template_file))
  except:
    raise MaestroException('Error reading template file {}!'.format(template_filename))
  with open(output_file, "w") as f:
    f.write(template.render(conf))


def configure():
  """ Generate nifi configuration from enviornment variables
  """
  logger.info('Configuring Nifi.')

  conf = {}
  logger.info('conf={}'.format(conf))
  render('nifi.properties', conf)

 # cp /opt/nifi_CENX/nifi_templates/* /opt/nifi/conf/templates/
#shutil.copytree(os.path.join(/opt/nifi_CENX/nifi_templates/, 'configuration'), os.path.join(/opt/nifi/conf/templates/, 'configuration'))
copy_tree("/opt/nifi_CENX/nifi_templates/", "/opt/nifi/conf/templates/")


def run():
  logger.info('Starting Nifi.')
  os.execl('/opt/nifi/bin/nifi.sh', 'nifi.sh', 'run')


def main():
  configure()
  run()

if __name__ == "__main__":
  main()
